Clazz.declarePackage("JSV.api.js");
Clazz.declareInterface(JSV.api.js, "JSVAppletObject", javajs.api.js.JSAppletObject);
;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
